@@ -554,6 +554,51 @@ class DescribeMachineUnderwriteResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeQualityScoreRequest(AbstractModel):
+    """DescribeQualityScore请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param File: 文件二进制数据
+        :type File: binary
+        """
+        self.File = None
+
+
+    def _deserialize(self, params):
+        self.File = params.get("File")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeQualityScoreResponse(AbstractModel):
+    """DescribeQualityScore返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param QualityScore: 质量分
+        :type QualityScore: float
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.QualityScore = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.QualityScore = params.get("QualityScore")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeReportClassifyRequest(AbstractModel):
     """DescribeReportClassify请求参数结构体
 
@@ -1011,6 +1056,35 @@ class InsuranceResult(AbstractModel):
         
 
 
+class Location(AbstractModel):
+    """位置信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Points: 位置信息
+        :type Points: list of Point
+        """
+        self.Points = None
+
+
+    def _deserialize(self, params):
+        if params.get("Points") is not None:
+            self.Points = []
+            for item in params.get("Points"):
+                obj = Point()
+                obj._deserialize(item)
+                self.Points.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class MachinePredict(AbstractModel):
     """机器核保预测结果
 
@@ -1103,6 +1177,44 @@ class MachineUnderwriteOutput(AbstractModel):
         
 
 
+class OcrRecognise(AbstractModel):
+    """Ocr识别结果
+
+    """
+
+    def __init__(self):
+        r"""
+        :param OriginalField: 原文字段
+        :type OriginalField: str
+        :param Value: 识别结果
+        :type Value: str
+        :param Confidence: 置信度
+        :type Confidence: float
+        :param Location: 位置信息
+        :type Location: :class:`tencentcloud.cii.v20210408.models.Location`
+        """
+        self.OriginalField = None
+        self.Value = None
+        self.Confidence = None
+        self.Location = None
+
+
+    def _deserialize(self, params):
+        self.OriginalField = params.get("OriginalField")
+        self.Value = params.get("Value")
+        self.Confidence = params.get("Confidence")
+        if params.get("Location") is not None:
+            self.Location = Location()
+            self.Location._deserialize(params.get("Location"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class PerStructDifference(AbstractModel):
     """复核差异接口的每一份报告的差异结果
 
@@ -1158,6 +1270,38 @@ class PerStructDifference(AbstractModel):
         
 
 
+class Point(AbstractModel):
+    """点信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param XCoordinate: x坐标
+        :type XCoordinate: int
+        :param YCoordinate: y坐标
+        :type YCoordinate: int
+        :param Page: 页码
+        :type Page: int
+        """
+        self.XCoordinate = None
+        self.YCoordinate = None
+        self.Page = None
+
+
+    def _deserialize(self, params):
+        self.XCoordinate = params.get("XCoordinate")
+        self.YCoordinate = params.get("YCoordinate")
+        self.Page = params.get("Page")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class ResultObject(AbstractModel):
     """用于返回结构化任务结果
 
@@ -1312,11 +1456,18 @@ class StructureResultObject(AbstractModel):
         :type StructureResult: str
         :param SubTaskId: 子任务ID
         :type SubTaskId: str
+        :param TaskFiles: 任务文件列表
+        :type TaskFiles: list of str
+        :param ResultFields: 结构化字段结果数组
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ResultFields: list of OcrRecognise
         """
         self.Code = None
         self.TaskType = None
         self.StructureResult = None
         self.SubTaskId = None
+        self.TaskFiles = None
+        self.ResultFields = None
 
 
     def _deserialize(self, params):
@@ -1324,6 +1475,13 @@ class StructureResultObject(AbstractModel):
         self.TaskType = params.get("TaskType")
         self.StructureResult = params.get("StructureResult")
         self.SubTaskId = params.get("SubTaskId")
+        self.TaskFiles = params.get("TaskFiles")
+        if params.get("ResultFields") is not None:
+            self.ResultFields = []
+            for item in params.get("ResultFields"):
+                obj = OcrRecognise()
+                obj._deserialize(item)
+                self.ResultFields.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1378,16 +1536,51 @@ class UnderwriteItem(AbstractModel):
         :type Result: str
         :param Value: 风险值或者说明
         :type Value: str
+        :param Range: 参考范围
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Range: str
+        :param ReportDate: 报告时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ReportDate: list of str
+        :param FileType: 文件类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FileType: str
+        :param InspectProject: 检查项目
+注意：此字段可能返回 null，表示取不到有效值。
+        :type InspectProject: str
+        :param Unit: 单位
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Unit: str
+        :param OriginName: 原名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OriginName: str
+        :param YinYang: 阴阳性
+注意：此字段可能返回 null，表示取不到有效值。
+        :type YinYang: str
         """
         self.Name = None
         self.Result = None
         self.Value = None
+        self.Range = None
+        self.ReportDate = None
+        self.FileType = None
+        self.InspectProject = None
+        self.Unit = None
+        self.OriginName = None
+        self.YinYang = None
 
 
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Result = params.get("Result")
         self.Value = params.get("Value")
+        self.Range = params.get("Range")
+        self.ReportDate = params.get("ReportDate")
+        self.FileType = params.get("FileType")
+        self.InspectProject = params.get("InspectProject")
+        self.Unit = params.get("Unit")
+        self.OriginName = params.get("OriginName")
+        self.YinYang = params.get("YinYang")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
